@@ -1,16 +1,16 @@
 #!/usr/bin/env bash
-# Copyright 1999-2021 Gentoo Authors
+# Copyright 1999-2023 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
 if ___eapi_has_DESTTREE_INSDESTTREE; then
 	export DESTTREE=/usr
 	export INSDESTTREE=""
 else
-	export _E_DESTTREE_=/usr
-	export _E_INSDESTTREE_=""
+	export __E_DESTTREE=/usr
+	export __E_INSDESTTREE=""
 fi
-export _E_EXEDESTTREE_=""
-export _E_DOCDESTTREE_=""
+export __E_EXEDESTTREE=""
+export __E_DOCDESTTREE=""
 export INSOPTIONS="-m0644"
 export EXEOPTIONS="-m0755"
 export LIBOPTIONS="-m0644"
@@ -26,14 +26,14 @@ declare -a PORTAGE_DOSTRIP_SKIP=()
 
 into() {
 	if [[ "$1" == "/" ]]; then
-		export _E_DESTTREE_=""
+		export __E_DESTTREE=""
 	else
-		export _E_DESTTREE_=$1
+		export __E_DESTTREE=$1
 		if ! ___eapi_has_prefix_variables; then
 			local ED=${D}
 		fi
-		if [[ ! -d "${ED%/}/${_E_DESTTREE_#/}" ]]; then
-			install -d "${ED%/}/${_E_DESTTREE_#/}"
+		if [[ ! -d "${ED%/}/${__E_DESTTREE#/}" ]]; then
+			install -d "${ED%/}/${__E_DESTTREE#/}"
 
 			local ret=$?
 			if [[ ${ret} -ne 0 ]] ; then
@@ -44,20 +44,20 @@ into() {
 	fi
 
 	if ___eapi_has_DESTTREE_INSDESTTREE; then
-		export DESTTREE=${_E_DESTTREE_}
+		export DESTTREE=${__E_DESTTREE}
 	fi
 }
 
 insinto() {
 	if [[ "${1}" == "/" ]]; then
-		export _E_INSDESTTREE_=""
+		export __E_INSDESTTREE=""
 	else
-		export _E_INSDESTTREE_=${1}
+		export __E_INSDESTTREE=${1}
 		if ! ___eapi_has_prefix_variables; then
 			local ED=${D}
 		fi
-		if [[ ! -d "${ED%/}/${_E_INSDESTTREE_#/}" ]]; then
-			install -d "${ED%/}/${_E_INSDESTTREE_#/}"
+		if [[ ! -d "${ED%/}/${__E_INSDESTTREE#/}" ]]; then
+			install -d "${ED%/}/${__E_INSDESTTREE#/}"
 
 			local ret=$?
 			if [[ ${ret} -ne 0 ]] ; then
@@ -68,20 +68,20 @@ insinto() {
 	fi
 
 	if ___eapi_has_DESTTREE_INSDESTTREE; then
-		export INSDESTTREE=${_E_INSDESTTREE_}
+		export INSDESTTREE=${__E_INSDESTTREE}
 	fi
 }
 
 exeinto() {
 	if [[ "${1}" == "/" ]]; then
-		export _E_EXEDESTTREE_=""
+		export __E_EXEDESTTREE=""
 	else
-		export _E_EXEDESTTREE_="${1}"
+		export __E_EXEDESTTREE="${1}"
 		if ! ___eapi_has_prefix_variables; then
 			local ED=${D}
 		fi
-		if [[ ! -d "${ED%/}/${_E_EXEDESTTREE_#/}" ]]; then
-			install -d "${ED%/}/${_E_EXEDESTTREE_#/}"
+		if [[ ! -d "${ED%/}/${__E_EXEDESTTREE#/}" ]]; then
+			install -d "${ED%/}/${__E_EXEDESTTREE#/}"
 
 			local ret=$?
 			if [[ ${ret} -ne 0 ]] ; then
@@ -94,14 +94,14 @@ exeinto() {
 
 docinto() {
 	if [[ "${1}" == "/" ]]; then
-		export _E_DOCDESTTREE_=""
+		export __E_DOCDESTTREE=""
 	else
-		export _E_DOCDESTTREE_="${1}"
+		export __E_DOCDESTTREE="${1}"
 		if ! ___eapi_has_prefix_variables; then
 			local ED=${D}
 		fi
-		if [[ ! -d "${ED%/}/usr/share/doc/${PF}/${_E_DOCDESTTREE_#/}" ]]; then
-			install -d "${ED%/}/usr/share/doc/${PF}/${_E_DOCDESTTREE_#/}"
+		if [[ ! -d "${ED%/}/usr/share/doc/${PF}/${__E_DOCDESTTREE#/}" ]]; then
+			install -d "${ED%/}/usr/share/doc/${PF}/${__E_DOCDESTTREE#/}"
 			local ret=$?
 			if [[ ${ret} -ne 0 ]] ; then
 				__helpers_die "${FUNCNAME[0]} failed"
@@ -643,13 +643,15 @@ econf() {
 			fi
 
 			if ___eapi_econf_passes_--disable-dependency-tracking; then
-				if [[ ${conf_help} == *--disable-dependency-tracking* ]]; then
+				if [[ ${conf_help} == \
+						*--disable-dependency-tracking[^A-Za-z0-9+_.-]* ]]; then
 					conf_args+=( --disable-dependency-tracking )
 				fi
 			fi
 
 			if ___eapi_econf_passes_--disable-silent-rules; then
-				if [[ ${conf_help} == *--disable-silent-rules* ]]; then
+				if [[ ${conf_help} == \
+						*--disable-silent-rules[^A-Za-z0-9+_.-]* ]]; then
 					conf_args+=( --disable-silent-rules )
 				fi
 			fi
@@ -672,20 +674,20 @@ econf() {
 			fi
 
 			if ___eapi_econf_passes_--with-sysroot; then
-				if [[ ${conf_help} == *--with-sysroot* ]]; then
+				if [[ ${conf_help} == *--with-sysroot[^A-Za-z0-9+_.-]* ]]; then
 					conf_args+=( --with-sysroot="${ESYSROOT:-/}" )
 				fi
 			fi
 		fi
 
 		# If the profile defines a location to install libs to aside from default, pass it on.
-		# If the ebuild passes in --libdir, they're responsible for the conf_libdir fun.
-		local CONF_LIBDIR LIBDIR_VAR="LIBDIR_${ABI}"
-		if [[ -n ${ABI} && -n ${!LIBDIR_VAR} ]] ; then
-			CONF_LIBDIR=${!LIBDIR_VAR}
+		# If the ebuild passes in --libdir, they're responsible for the libdir fun.
+		local libdir libdir_var="LIBDIR_${ABI}"
+		if [[ -n ${ABI} && -n ${!libdir_var} ]] ; then
+			libdir=${!libdir_var}
 		fi
 
-		if [[ -n ${CONF_LIBDIR} ]] && ! __hasgq --libdir=\* "$@" ; then
+		if [[ -n ${libdir} ]] && ! __hasgq --libdir=\* "$@" ; then
 			export CONF_PREFIX=$(__hasg --exec-prefix=\* "$@")
 			[[ -z ${CONF_PREFIX} ]] && CONF_PREFIX=$(__hasg --prefix=\* "$@")
 
@@ -693,10 +695,10 @@ econf() {
 			CONF_PREFIX=${CONF_PREFIX#*=}
 
 			[[ ${CONF_PREFIX} != /* ]] && CONF_PREFIX="/${CONF_PREFIX}"
-			[[ ${CONF_LIBDIR} != /* ]] && CONF_LIBDIR="/${CONF_LIBDIR}"
+			[[ ${libdir} != /* ]] && libdir="/${libdir}"
 
 			conf_args+=(
-				--libdir="$(__strip_duplicate_slashes "${CONF_PREFIX}${CONF_LIBDIR}")"
+				--libdir="$(__strip_duplicate_slashes "${CONF_PREFIX}${libdir}")"
 			)
 		fi
 
@@ -749,17 +751,15 @@ einstall() {
 		local ED=${D}
 	fi
 
-	LIBDIR_VAR="LIBDIR_${ABI}"
-	if [[ -n "${ABI}" && -n "${!LIBDIR_VAR}" ]]; then
-		CONF_LIBDIR="${!LIBDIR_VAR}"
+	local libdir libdir_var="LIBDIR_${ABI}"
+	if [[ -n "${ABI}" && -n "${!libdir_var}" ]]; then
+		libdir="${!libdir_var}"
 	fi
-	unset LIBDIR_VAR
 
-	if [[ -n "${CONF_LIBDIR}" && "${CONF_PREFIX:+set}" = set ]]; then
-		EI_DESTLIBDIR="${D%/}/${CONF_PREFIX}/${CONF_LIBDIR}"
-		EI_DESTLIBDIR="$(__strip_duplicate_slashes "${EI_DESTLIBDIR}")"
-		LOCAL_EXTRA_EINSTALL="libdir=${EI_DESTLIBDIR} ${LOCAL_EXTRA_EINSTALL}"
-		unset EI_DESTLIBDIR
+	if [[ -n "${libdir}" && "${CONF_PREFIX:+set}" = set ]]; then
+		local destlibdir="${D%/}/${CONF_PREFIX}/${libdir}"
+		destlibdir="$(__strip_duplicate_slashes "${destlibdir}")"
+		LOCAL_EXTRA_EINSTALL="libdir=${destlibdir} ${LOCAL_EXTRA_EINSTALL}"
 	fi
 
 	if [[ -f Makefile || -f GNUmakefile || -f makefile ]] ; then
@@ -963,7 +963,7 @@ ___best_version_and_has_version_common() {
 	if [[ -n ${PORTAGE_IPC_DAEMON} ]] ; then
 		cmd+=("${PORTAGE_BIN_PATH}"/ebuild-ipc "${FUNCNAME[1]}" "${root}" "${atom}")
 	else
-		cmd+=("${PORTAGE_BIN_PATH}"/ebuild-helpers/portageq "${FUNCNAME[1]}" "${root}" "${atom}")
+		cmd+=("${PORTAGE_BIN_PATH}"/portageq-wrapper "${FUNCNAME[1]}" "${root}" "${atom}")
 	fi
 
 	"${cmd[@]}"
