@@ -47,7 +47,7 @@ class EverythingSet(PackageSet):
                 # SLOT installed, in order to avoid the possibility
                 # of unwanted upgrades as reported in bug #338959.
                 pkg = pkg_str(cpv, None)
-                atom = Atom("{}:{}".format(pkg.cp, pkg.slot))
+                atom = Atom(f"{pkg.cp}:{pkg.slot}")
                 if self._filter:
                     if self._filter(atom):
                         myatoms.append(atom)
@@ -63,7 +63,6 @@ class EverythingSet(PackageSet):
 
 
 class OwnerSet(PackageSet):
-
     _operations = ["merge", "unmerge"]
 
     description = (
@@ -105,7 +104,7 @@ class OwnerSet(PackageSet):
         if not exclude_paths:
             for link, p in vardb._owners.iter_owners(paths):
                 pkg = pkg_str(link.mycpv, None)
-                rValue.add("{}:{}".format(pkg.cp, pkg.slot))
+                rValue.add(f"{pkg.cp}:{pkg.slot}")
         else:
             all_paths = set()
             all_paths.update(paths)
@@ -113,7 +112,7 @@ class OwnerSet(PackageSet):
             exclude_atoms = set()
             for link, p in vardb._owners.iter_owners(all_paths):
                 pkg = pkg_str(link.mycpv, None)
-                atom = "{}:{}".format(pkg.cp, pkg.slot)
+                atom = f"{pkg.cp}:{pkg.slot}"
                 rValue.add(atom)
                 # Returned paths are relative to ROOT and do not have
                 # a leading slash.
@@ -145,7 +144,6 @@ class OwnerSet(PackageSet):
 
 
 class VariableSet(EverythingSet):
-
     _operations = ["merge", "unmerge"]
 
     description = (
@@ -221,7 +219,6 @@ class VariableSet(EverythingSet):
 
 
 class SubslotChangedSet(PackageSet):
-
     _operations = ["merge", "unmerge"]
 
     description = (
@@ -242,7 +239,7 @@ class SubslotChangedSet(PackageSet):
         cp_list = self._vardb.cp_list
         for cp in self._vardb.cp_all():
             for pkg in cp_list(cp):
-                slot_atom = "{}:{}".format(pkg.cp, pkg.slot)
+                slot_atom = f"{pkg.cp}:{pkg.slot}"
                 ebuild = xmatch(xmatch_level, slot_atom)
                 if not ebuild:
                     continue
@@ -258,7 +255,6 @@ class SubslotChangedSet(PackageSet):
 
 
 class DowngradeSet(PackageSet):
-
     _operations = ["merge", "unmerge"]
 
     description = (
@@ -281,7 +277,7 @@ class DowngradeSet(PackageSet):
         for cp in self._vardb.cp_all():
             for cpv in cp_list(cp):
                 pkg = pkg_str(cpv, None)
-                slot_atom = "{}:{}".format(pkg.cp, pkg.slot)
+                slot_atom = f"{pkg.cp}:{pkg.slot}"
                 ebuild = xmatch(xmatch_level, slot_atom)
                 if not ebuild:
                     continue
@@ -297,7 +293,6 @@ class DowngradeSet(PackageSet):
 
 
 class UnavailableSet(EverythingSet):
-
     _operations = ["unmerge"]
 
     description = (
@@ -314,7 +309,6 @@ class UnavailableSet(EverythingSet):
         return not self._metadatadb.match(atom)
 
     def singleBuilder(cls, options, settings, trees):
-
         metadatadb = options.get("metadata-source", "porttree")
         if not metadatadb in trees:
             raise SetConfigError(
@@ -327,7 +321,6 @@ class UnavailableSet(EverythingSet):
 
 
 class UnavailableBinaries(EverythingSet):
-
     _operations = (
         "merge",
         "unmerge",
@@ -351,7 +344,6 @@ class UnavailableBinaries(EverythingSet):
         return not self._metadatadb.cpv_exists(inst_cpv)
 
     def singleBuilder(cls, options, settings, trees):
-
         metadatadb = options.get("metadata-source", "bintree")
         if not metadatadb in trees:
             raise SetConfigError(
@@ -460,7 +452,6 @@ class AgeSet(EverythingSet):
         self._age = age
 
     def _filter(self, atom):
-
         cpv = self._db.match(atom)[0]
         try:
             (date,) = self._db.aux_get(cpv, self._aux_keys)
@@ -499,7 +490,6 @@ class DateSet(EverythingSet):
         self._date = date
 
     def _filter(self, atom):
-
         cpv = self._db.match(atom)[0]
         try:
             (date,) = self._db.aux_get(cpv, self._aux_keys)
@@ -608,7 +598,6 @@ class RebuiltBinaries(EverythingSet):
 
 
 class ChangedDepsSet(PackageSet):
-
     _operations = ["merge", "unmerge"]
 
     description = (
@@ -672,7 +661,7 @@ class ChangedDepsSet(PackageSet):
 
             # if dependencies don't match, trigger the rebuild.
             if vdbvars != pdbvars:
-                atoms.append("=%s" % cpv)
+                atoms.append(f"={cpv}")
 
         self._setAtoms(atoms)
 
