@@ -1,9 +1,11 @@
-# Copyright 2017 Gentoo Foundation
+# Copyright 2017, 2023 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
 
 import shutil
 import tempfile
 
+import pytest
+
 from portage import os
 from portage.tests import TestCase
 from portage.checksum import perform_md5
@@ -55,8 +57,14 @@ class CopyFileSparseTestCase(TestCase):
 
             # This last part of the test is expected to fail when sparse
             # copy is not implemented, so set the todo flag in order
-            # to tolerate failures.
-            self.todo = True
+            # to tolerate failures. Or mark it xfail:
+
+            AM_I_UNDER_PYTEST = "PYTEST_CURRENT_TEST" in os.environ
+
+            if AM_I_UNDER_PYTEST:
+                pytest.xfail(reason="sparse copy is not implemented")
+            else:
+                self.todo = True
 
             # If sparse blocks were preserved, then both files should
             # consume the same number of blocks.
